@@ -1,4 +1,5 @@
 mod create_behaviors;
+mod create_matchers;
 mod item_impl;
 mod item_struct;
 mod item_trait;
@@ -8,6 +9,7 @@ mod type_name;
 use proc_macro2::TokenStream;
 use quote::ToTokens;
 use syn::visit_mut::VisitMut;
+mod alphabets;
 use syn::{parse, parse2, parse_macro_input, ExprStruct, ItemImpl, ItemStruct, ItemTrait};
 
 enum Target {
@@ -42,7 +44,12 @@ pub fn new(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
 
 #[proc_macro]
 pub fn create_behaviors(_: proc_macro::TokenStream) -> proc_macro::TokenStream {
-    proc_macro::TokenStream::from(create_behaviors::create())
+    create_behaviors::create().into()
+}
+
+#[proc_macro]
+pub fn create_matchers(_: proc_macro::TokenStream) -> proc_macro::TokenStream {
+    create_matchers::create().into()
 }
 
 struct M(TokenStream);
